@@ -62,10 +62,10 @@ pod2usage( -message => "Incorrect number of arguments",
 #     3. or else, distribution folder
 my $home = $^O eq 'MSWin32' ? $ENV{'userprofile'} : $ENV{'HOME'};
 my $configDir = $ENV{'BEAMERREVEAL_CONFIG'}
-  // File::Spec->catfile( $home, '.config', 'beamer-reveal' );
+  // File::Spec->catfile( $home, '.config', 'BeamerReveal' );
 my $configFileName = File::Spec->catfile( $configDir, 'config.ini' );
 $configFileName =
-  File::Spec->catfile( File::ShareDir::dist_dir( 'beamer-reveal' ) ,
+  File::Spec->catfile( File::ShareDir::dist_dir( 'BeamerReveal' ) ,
 		       'config.ini' ) if ( ! -r $configFileName );
 dieExit( 13, "Error: cannot find config file" )
   unless( -r $configFileName );
@@ -216,7 +216,7 @@ beamer-reveal.pl - converts the .rvl file and the corresponding pdf file to a fu
 
 =head1 VERSION
 
-version 20251224.1235
+version 20251224.1248
 
 =head1 SYNOPSIS
 
