@@ -107,7 +107,7 @@ sub new {
 sub revealToStore {
   my $self = shift;
 
-  my $revealTree = File::Spec->catfile( File::ShareDir::dist_dir( 'beamer-reveal' ),
+  my $revealTree = File::Spec->catfile( File::ShareDir::dist_dir( 'BeamerReveal' ),
 					'libs' );
   my $destTree = $self->{reveal};
 
@@ -347,7 +347,7 @@ BeamerReveal::MediaManager - MediaManager
 
 =head1 VERSION
 
-version 20251224.1235
+version 20251224.1248
 
 =head1 SYNOPSIS
 
